Crate redox_installer

Crate redox_installer 

Structs

Config
DiskOption
FileConfig

Enums

PackageConfig

Functions

fetch_bootloaders
install
Install RedoxFS into a new disk file, or a sysroot directory. This function assumes all interactive prompts resolved by the caller.
install_dir
prompt_password
Returns a password collected from the user (plaintext)
try_fast_install
with_redoxfs
with_redoxfs_ar
with_redoxfs_mount
with_whole_disk