Structs
Enums
Functions
- fetch_
bootloaders - install
- Install RedoxFS into a new disk file, or a sysroot directory. This function assumes all interactive prompts resolved by the caller.
- install_
dir - prompt_
password - Returns a password collected from the user (plaintext)
- try_
fast_ install - with_
redoxfs - with_
redoxfs_ ar - with_
redoxfs_ mount - with_
whole_ disk